TRUE if x (tensor or matrix) holds any NA/NaN/
Inf. On a tensor this is a scalar reduction copied back, not a full
GPU->CPU materialisation of x.
TRUE if x (tensor or matrix) holds any NA/NaN/
Inf. On a tensor this is a scalar reduction copied back, not a full
GPU->CPU materialisation of x.