Clears the session-level cache of the resolved torch device and memory
budget (set by getBackendDevice/getGPUMemoryBudget).
Useful in tests, or if the available device/memory changes within a session.
Clears the session-level cache of the resolved torch device and memory
budget (set by getBackendDevice/getGPUMemoryBudget).
Useful in tests, or if the available device/memory changes within a session.